==> dashboard-skeleton-compostrap-1.0.9.tgz: package/readme.md <==
<p align="center">
  <img src="https://avatars0.githubusercontent.com/u/50230834?s=400&u=3551f498f489486fb0ee563171d5fb2d43892a17&v=4" width="100" alt="logo">
</p>

<h3 align="center">Compostrap</h3>
<p align="center">Simple and fast components build on Bootstrap 4</p>

## Dashboard skeleton
Simple and fast dashboard skeleton template.

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://raw.githubusercontent.com/compostrap/dashboard-skeleton/master/license.md)
[![npm version](https://badge.fury.io/js/dashboard-skeleton-compostrap.svg)](https://badge.fury.io/js/dashboard-skeleton-compostrap)
[![Build Status](https://travis-ci.com/compostrap/dashboard-skeleton.svg?branch=master)](https://travis-ci.com/compostrap/dashboard-skeleton)
[![CodeFactor](https://www.codefactor.io/repository/github/compostrap/dashboard-skeleton/badge)](https://www.codefactor.io/repository/github/compostrap/dashboard-skeleton)

## Installation
```
npm install --save dashboard-skeleton-compostrap
```

## Built on
- [Bootstrap 4](https://getbootstrap.com)
- [jQuery](https://jquery.com)
- [Font Awesome 5](https://fontawesome.com)
- [Perfect scrollbar](https://github.com/mdbootstrap/perfect-scrollbar)
- [Open Sans @font-face kit](https://github.com/FontFaceKit/open-sans)
- [Nanobar](https://github.com/jacoborus/nanobar)

## Demo
https://compostrap.github.io/dashboard.skeleton

## Introduction
Simple and fast dashbaord skeleton is build on Bootstrap. So you should be aware of how Bootstrap itself is used.
The advantage is also knowledge of sass, npm, grunt.

## Dashboard skeleton
The basic skeleton consists of these components.

- [Sidebar skeleton](https://github.com/compostrap/sidebar-skeleton)
- [Sidebar menu](https://github.com/compostrap/sidebar-menu)

## Dashboard extension
Added some classes for text.

| Color                                                               | Class         |
| ------------------------------------------------------------------- | ------------- |
| ![#6f42c1](https://placehold.it/15/6f42c1/000000?text=+) `#6f42c1`  | `text-purple` |
| ![#e83e8c](https://placehold.it/15/e83e8c/000000?text=+) `#e83e8c`  | `text-pink`   |
| ![#fd7e14](https://placehold.it/15/fd7e14/000000?text=+) `#fd7e14`  | `text-orange` |
| ![#20c997](https://placehold.it/15/20c997/000000?text=+) `#20c997`  | `text-teal`   |

| Description | class          |
| ----------- | -------------- |
| Fatty text  | `text-bolder` |

==> dashboard-skeleton-compostrap-2.0.4.tgz: package/readme.md <==
<p align="center">
  <img src="https://avatars0.githubusercontent.com/u/50230834?s=400&u=3551f498f489486fb0ee563171d5fb2d43892a17&v=4" width="100" alt="logo">
</p>

<h3 align="center">Compostrap</h3>
<p align="center">Simple and fast components build on Bootstrap</p>

## Dashboard skeleton
Simple and fast dashboard skeleton template.

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://raw.githubusercontent.com/compostrap/dashboard-skeleton/master/license.md)
[![npm version](https://badge.fury.io/js/dashboard-skeleton-compostrap.svg)](https://badge.fury.io/js/dashboard-skeleton-compostrap)
[![Build Status](https://travis-ci.com/compostrap/dashboard-skeleton.svg?branch=master)](https://travis-ci.com/compostrap/dashboard-skeleton)
[![CodeFactor](https://www.codefactor.io/repository/github/compostrap/dashboard-skeleton/badge)](https://www.codefactor.io/repository/github/compostrap/dashboard-skeleton)

## Installation
```
npm install --save dashboard-skeleton-compostrap
```

Version 1x built on Bootstrap 4  
Version 2x built on Bootstrap 5

## Built on
- [Bootstrap](https://getbootstrap.com)
- [jQuery](https://jquery.com)
- [Font Awesome 5](https://fontawesome.com)
- [Perfect scrollbar](https://github.com/mdbootstrap/perfect-scrollbar)
- [Open Sans @font-face kit](https://github.com/FontFaceKit/open-sans)
- [Nanobar](https://github.com/jacoborus/nanobar)

## Demo
https://compostrap.github.io/dashboard.skeleton

## Introduction
Simple and fast dashbaord skeleton is build on Bootstrap. So you should be aware of how Bootstrap itself is used.
The advantage is also knowledge of sass, npm, grunt.

## Dashboard skeleton
The basic skeleton consists of these components.

- [Sidebar skeleton](https://github.com/compostrap/sidebar-skeleton)
- [Sidebar menu](https://github.com/compostrap/sidebar-menu)

## Dashboard extension
Added some classes for text.

| Color                                                           | Class         |
| --------------------------------------------------------------- | ------------- |
| ![#6f42c1](https://via.placeholder.com/15/6f42c1/000000?text=+) | `text-purple` |
| ![#e83e8c](https://via.placeholder.com/15/e83e8c/000000?text=+) | `text-pink`   |
| ![#fd7e14](https://via.placeholder.com/15/fd7e14/000000?text=+) | `text-orange` |
| ![#20c997](https://via.placeholder.com/15/20c997/000000?text=+) | `text-teal`   |

| Description | class          |
| ----------- | -------------- |
| Fatty text  | `text-bolder` |
